//
//		Definition of the main game class
//
#ifndef THE_FLOATING_ANIMS_H
#define THE_FLOATING_ANIMS_H

#include "theGraphicsManager.h"

class theGameState;

//CLASS DEFINES
#define animFramesToSkip		1 // was 5 but we do it twice now
#define maxNumFloatingAnims		512

//...typedefs etc

typedef enum
{
	eSparkleRedAnim,
	eEmptyAnim,
	eSparkleYellowAnim,
	eWhiteSparkleAnim,
	eWhiteSparkleBigAnim,
	eDirt,
	eDust1,
	eDust2,
	eWater,
	eFood,
	ePollen,
	eSpray,
	eSprayRed,
	eSprayBlue,
	eSprayPurple,
	eSprayYellow,
	eSharpSparkleAnim,
	eBlurrySparkleAnim,
	eBees,
	eWaterfall2Anim,
	eWaterfallFoamAnim,
	eWaterSprayAnim,
	eBirdhouseAnim,
	eTurtleSquirtAnim,
	eGlowingFrame

}
FloatingAnimationType;

typedef enum
{
	eRising1,
	eFalling1,
	eFalling2,
	eVibrating,
	eFloating,
	eLaunching1,
	eBlowing,
	eNoEffect
} AnimEffectEnum;	

typedef enum
{
	eFG,
	eBG,
	eOverlay

} FgOrBgEnum;

typedef struct 
{	
	FloatingAnimationType animType;
	AnimEffectEnum 		  animEffect;
	FgOrBgEnum            animDepth;
	ImageId               imageId;

	ldwPoint   pos;
	int        currentFrame;
	int        numFrames;
	int        animSpeed; //fastest will never be faster than animFramesToSkip allows.  Setting this fastest will cause animIdx to trigger at 1.
	int        animIdx; //counts number of Update 'visits'.  when this triggers (based on animSpeed), currentFrame is ++.
	ldwPoint positionOffsetCounter;
	ldwPoint velocity;
	int        whichItem;
	bool       looping;
	bool       exists;


}
FloatingAnimType;
//END DEFINES

//BEGIN CLASS DECLARATION
class theFloatingAnims 
{
public:

	theFloatingAnims();
	~theFloatingAnims();
	static theFloatingAnims * Get();
	static void Destroy();

	bool AddAnim(FloatingAnimationType whichAnim);
	bool AddAnim(FloatingAnimationType whichAnim, ldwPoint animPos);
	bool AddAnim(FloatingAnimationType whichAnim, ldwPoint animPos,  bool loops);
	bool AddAnim(FloatingAnimationType whichAnim, ldwPoint animPos, int howFast, bool loops);
	bool AddAnim(FloatingAnimationType whichAnim, ldwPoint animPos, int howFast, bool loops, AnimEffectEnum whatEffect);
    
	bool AddAnim(FloatingAnimationType whichAnim, ldwPoint animPos, int howFast, FgOrBgEnum animLevel);
	bool AddAnim(FloatingAnimationType whichAnim, ldwPoint animPos,  bool loops, FgOrBgEnum animLevel);
	bool AddAnim(FloatingAnimationType whichAnim, ldwPoint animPos, int howFast, bool loops, FgOrBgEnum animLevel);
	bool AddAnim(FloatingAnimationType whichAnim, ldwPoint animPos, int howFast, bool loops, AnimEffectEnum whatEffect, FgOrBgEnum animLevel);
	
	bool AddAnim(FloatingAnimationType whichAnim, ldwPoint animPos, int howFast, bool loops, AnimEffectEnum whatEffect, ldwPoint vector1); //this one only for anims that need a vector passed in

	void StopAnim(FloatingAnimationType whichAnim);
	void StopAnims();

	bool PopulateThisAnim(FloatingAnimationType whichAnim, ldwPoint animPos, int howFast, bool loops, AnimEffectEnum whatEffect, FgOrBgEnum animLevel);   
	void modifyDrawPos(int animPosInArray);

	void ProcessAnims();

protected:
	


	bool PurgeAnim(int animPosInArray); //turn off the anim, resetting all values.  should look very similar to the constructor init of the anim struct.
	//void UpdateScene();
	//void DrawUI();
	static theFloatingAnims *mInstance;

private:

	int animationAdvancementCounter; //when this reaches animFramesToSkip, do an actual update. . then we know we are coming in framerate/animFrameToSkip times per sec
	ldwPoint tempVector;

	FloatingAnimType floatingAnimArray[maxNumFloatingAnims];
	
	theGameState  *gs;

	int animFrames;
    bool animLooping;
};
#endif